

#include <stdio.h>
#include <stdlib.h>


// AxisOverlap determines if two ranges on the numberline overlap.
// First, it checks if the two ranges are separated, such that
// a is to the left of b, or b is to the left of a.  Then, it negates
// this result--two ranges overlap if and only if they are not separated.
//
int AxisOverlap(int a_min, int a_max, int b_min, int b_max)
{
    return !(a_max <= b_min || a_min >= b_max);
}

// BoxOverlap determines if two boxes, specified as {x-min, x-max, y-min, y-max},
// are overlapping.  Two boxes overlap if and only if they intersect along the
// x and y axes.  Thus, this test can be implemented by using the above function,
// AxisOverlap, to check for intersection on both the x and y axes.
//
int BoxOverlap(int a[4], int b[4])
{
    return AxisOverlap(a[0], a[1], b[0], b[1]) && 
           AxisOverlap(a[2], a[3], b[2], b[3]);   
}


int main()
{
    int number_of_boxes;
	int boxes[100][4];
	int overlaps[100];
    int i, j, overlap;
	
	// read in the boxes
	scanf("%d", &number_of_boxes);
    for(i = 0; i < number_of_boxes; i++)
    {
        // each box has four coordinates: x-min, x-max, y-min, y-max
        for(j = 0; j < 4; j++)
        {
            scanf("%d", &(boxes[i][j]));
        }
    }
    
    // compute which boxes overlap another box
    for(i = 0; i < number_of_boxes; i++)
    {
        // initialize each box i to have no overlaps
        overlaps[i] = 0;
        // search for overlap with any other box j, such that i != j
        for(j = 0; j < number_of_boxes; j++)
        {
            overlap = BoxOverlap(boxes[i], boxes[j]);
            overlaps[i] = overlaps[i] || (i != j && overlap);
        }
    }
    
    // print out box ids for boxes without any overlaps
    for(i = 0; i < number_of_boxes; i++)
    {
        if(overlaps[i] == 0)
        {
            printf("%d\n", i);
        }
    }
    return 0;
}


